@@ -199,9 +199,17 @@ typedef enum
   C_DESKTOP_STYLUS_BUTTON_ACTION_MIDDLE,
   C_DESKTOP_STYLUS_BUTTON_ACTION_RIGHT,
   C_DESKTOP_STYLUS_BUTTON_ACTION_BACK,
-  C_DESKTOP_STYLUS_BUTTON_ACTION_FORWARD
+  C_DESKTOP_STYLUS_BUTTON_ACTION_FORWARD,
+  C_DESKTOP_STYLUS_BUTTON_ACTION_DISABLED
 } CDesktopStylusButtonAction;
 
+typedef enum
+{
+  C_DESKTOP_NOTIFICATION_SCREEN_DISPLAY_PRIMARY_SCREEN,
+  C_DESKTOP_NOTIFICATION_SCREEN_DISPLAY_ACTIVE_SCREEN,
+  C_DESKTOP_NOTIFICATION_SCREEN_DISPLAY_FIXED_SCREEN
+} CDesktopNotificationScreenDisplay;
+
 typedef enum
 {
 /* All bindings before _SEPARATOR are treated as
